@@ -19,12 +19,12 @@ from urllib.parse import urljoin
 from urllib.request import pathname2url
 
 import numpy as np
-import sip
 
 from AnyQt.QtCore import Qt, QObject, QFile, QTimer, QUrl, QSize, QEventLoop, \
     pyqtProperty, pyqtSlot, pyqtSignal
 from AnyQt.QtGui import QColor
 from AnyQt.QtWidgets import QSizePolicy, QWidget, qApp
+from AnyQt import sip
 
 try:
     from AnyQt.QtWebKitWidgets import QWebView
@@ -533,7 +533,7 @@ elif HAVE_WEBENGINE:
             id = next(self._id_gen)
             value = self._objects[id] = dict(id=id, name=name, obj=obj)
             # Wait till JS is connected to receive objects
-            wait(until=lambda: self.receivers(self.objectChanged))
+            wait(until=lambda: self.receivers(self.objectChanged), timeout=30000)
             self.objectChanged.emit(value)
 
         @pyqtSlot(int)
